@@ -27,11 +27,13 @@ A somewhat more advanced version of the simple shell script - written for pymark
 # Please see the readme for usage instructions. 
 # We need some file operations
 from os import chdir, mkdir, listdir
-from os.path import isdir, join
+from os.path import isdir, join, isfile
 # And command line arguments
 from sys import argv
 # Also some string functions. 
 from string import replace
+# For timestamping some timestamps - I like it to know when sites where last changed :) 
+from time import strftime
 # And naturally markdown :) 
 from markdown import Markdown
 
@@ -47,14 +49,23 @@ STYLESHEET_NAME = "style.css" # inside the templates dir.
 # Before I really begin, add some "I am lazy and that is good" functions :) 
 
 def read_file(path): 
-    """Read all data from a file."""
-    f = open(path, "r")
-    data = f.read()
-    f.close()
+    """Read all data from a file. 
+
+If the file doesn't exist, just return an empty string.
+"""
+    try: 
+	f = open(path, "r")
+	data = f.read()
+	f.close()
+    except: 
+	data = ""
     return data
 
 def write_file(path, data): 
-    """Write all data into a file at the path - overwrite existing data."""
+    """Write all data into a file at the path - overwrite existing data.
+
+Raise an (automatic) exception if it doesn't work. 
+"""
     f = open(path, "w")
     f.write(data)
     f.close()
@@ -76,8 +87,8 @@ def prepare_the_target_dir(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK):
     write_file(join(TARGET_DIR, STYLESHEET_NAME), data)
 
 # Now create the markdown content of the index page. 
-def write_the_index(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK): 
-    """Write the index file."""
+def write_the_index(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK, force_update = False): 
+    """Write the index file - if anything was changed, add a new timestamp."""
     index = ""
 
     ## First the header
@@ -95,6 +106,10 @@ def write_the_index(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK):
 
     # At the end, add a link back to the main site. 
     index += "\n\n[" + LINK_BACK + "](" + LINK_BACK + ")"
+    
+    # Also add a date and time line. 
+    index += "\n\n --- " # A seperator - looks better. 
+    index += "\n\n -- *" + strftime('%Y-%m-%d %H:%M:%S') + "* --"
 
     ## Then compile it to html. 
 
@@ -115,37 +130,56 @@ def write_the_index(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK):
 
 # And compile every mdwn file to html
 
-def write_all_content_files(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK): 
+def write_all_content_files(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK, force_update = False): 
     """Compile all files in the dir with the .mdwn suffix to html and put them into the target dir."""
     # We need markdown again. 
     md = Markdown()
 
     ## Now the list of files
+    #: tracks if any file changed. 
+    changed = False
     for i in listdir(DIR_WITH_FILES): 
 	# Add a list of all markdown files
 	if i.endswith(".mdwn"): 
+	    # First read the current data. 
+	    # If it starts the same way (till the Markdown part finishes) the file didn't change, 
+	    # and we don't touch it. 
+	    old_data = read_file(join(TARGET_DIR, i[:-5] + ".html"))
+	    # First check the file. If nothing changed, don't change it (and don't update the timestamp). 
 	    data = read_file(join(TEMPLATE_DIR, "file_head.html"))
 	    # replace the title. 
 	    data = replace(data, "MARKDOWN_LIST", SITENAME)
 	    # Now convert the content. 
 	    markdown_data = read_file(i)
 	    data += md.convert(markdown_data)
-	    # and add a backlink. 
-	    data += "<a href='index.html'>" + SITENAME + "</a>"
+	    # if now old_data and new data fit, we jump to the next document, 
+	    # except if all sites MUST be reparsed. 
+	    if old_data[:len(data)] == data and not force_update: 
+		continue
+	    # If we get till here, the site changed and we need a new date line. 
+	    changed = True
+	    # and add a backlink and a date-line. 
+	    data += "\n<a href='index.html'>" + SITENAME + "</a>"
+	    data += "\n<hr>"
+	    data += "\n<p> -- <em>" + strftime('%Y-%m-%d %H:%M:%S') + "</em> -- </p>"
 	    # And in the end the footer. 
 	    data += read_file(join(TEMPLATE_DIR, "file_foot.html"))
 	    # and write the file. 
 	    write_file(join(TARGET_DIR, i[:-5] + ".html"), data)
+    
+    # We return the changed info, so the index only needs to be rebuilt, if some file changed. 
+    return changed
 
 # That's it! 
 
 # Now because I'm damn lazy: Write a wrap function :) 
 
-def parse_sites(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK): 
+def parse_sites(DIR_WITH_FILES, SITENAME, TARGET_DIR, LINK_BACK, force_update = False): 
     """Create the index and parse the content files."""
     prepare_the_target_dir(DIR_WITH_FILES = DIR_WITH_FILES, SITENAME = SITENAME, TARGET_DIR = TARGET_DIR, LINK_BACK = LINK_BACK)
-    write_the_index(DIR_WITH_FILES = DIR_WITH_FILES, SITENAME = SITENAME, TARGET_DIR = TARGET_DIR, LINK_BACK = LINK_BACK)
-    write_all_content_files(DIR_WITH_FILES = DIR_WITH_FILES, SITENAME = SITENAME, TARGET_DIR = TARGET_DIR, LINK_BACK = LINK_BACK)
+    changed = write_all_content_files(DIR_WITH_FILES = DIR_WITH_FILES, SITENAME = SITENAME, TARGET_DIR = TARGET_DIR, LINK_BACK = LINK_BACK, force_update = force_update)
+    if changed or force_update: 
+	write_the_index(DIR_WITH_FILES = DIR_WITH_FILES, SITENAME = SITENAME, TARGET_DIR = TARGET_DIR, LINK_BACK = LINK_BACK, force_update = force_update)
 
 
 #### Self-Test ####
@@ -156,19 +190,24 @@ def _test():
 
 if __name__ == "__main__": 
     # Provide help, if the commandline args don't fit. 
-    if len(argv) != 4 or len(argv) == 2 and argv[1] == "--help": 
+    if len(argv) < 4 or len(argv) == 2 and argv[1] == "--help": 
 	print help()
     elif len(argv) > 1 and argv[1] == "--help": 
 	print help()
     else: 
 
 	# Parse the commandline arguments. 
-	SITENAME = argv[1]
-	DIR_WITH_FILES = argv[2]
-	LINK_BACK = argv[3]
+	SITENAME = argv[-3]
+	DIR_WITH_FILES = argv[-2]
+	LINK_BACK = argv[-1]
+	if argv[1] == "--force-update": 
+	    force_update = True
+	else: 
+	    force_update = False
 
 	parse_sites(DIR_WITH_FILES = DIR_WITH_FILES, # Where the markdown files are
 			SITENAME = SITENAME, # The name of the site - Title and heading. 
 			TARGET_DIR = TARGET_DIR, # The dir, where the html should be stored. 
-			LINK_BACK = LINK_BACK # The link to the users main site (or any other site)
+			LINK_BACK = LINK_BACK, # The link to the users main site (or any other site)
+			force_update = force_update # If all sites MUST be parsed again - can be useful for template development. 
 		    )
