@@ -21,19 +21,24 @@
 """pyMarkdown Minisite - Parse a list of markdown files to a website with index. 
  
 Usage: 
- - parse_and_list_markdown_files.py "YOUR WEBSITES NAME" PATH_TO_YOUR_FILES_DIR http://YOUR_WEBSITES.URL
+ - parse_and_list_markdown_files.py [options] "YOUR WEBSITES NAME" PATH_TO_YOUR_FILES_DIR http://YOUR_WEBSITES.URL
   
    for default usage, or 
    
  - parse_and_list_markdown_files.py --help
    
    for getting help
+
+Options: 
+    --help - get help
+
+    --force-update - reparse all sites and update all date tags. 
   
 
 Examples: 
   - parse_and_list_markdown_files.py "pyMarkdown Minisite" . http://rakjar.de/pymarkdown_minisite/index.html
     
-    Parse this site. 
+    Parse the site of this script. 
 
 
 Plans: 
@@ -43,13 +48,14 @@ Plans:
 Ideas: 
   - Too many, so I keep them out just now :) 
 
+Website: U{http://rakjar.de/pymarkdown_minisite/}
 
 Source URL (Mercurial): U{http://freehg.org/u/ArneBab/pymarkdown_minisite/}
 
 PyPI URL: U{http://pypi.python.org/pypi/pymarkdown_minisite}
 """
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 def read_changelog():
     """Read and return the Changelog"""
